==> plasma-pa-5.7.0.tar.xz: plasma-pa-5.7.0/src/server.h <==
/*
    Copyright 2016 David Rosca <nowrep@gmail.com>

    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Lesser General Public
    License as published by the Free Software Foundation; either
    version 2.1 of the License, or (at your option) version 3, or any
    later version accepted by the membership of KDE e.V. (or its
    successor approved by the membership of KDE e.V.), which shall
    act as a proxy defined in Section 6 of version 3 of the license.

    This library is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
    Lesser General Public License for more details.

    You should have received a copy of the GNU Lesser General Public
    License along with this library.  If not, see <http://www.gnu.org/licenses/>.
*/

#ifndef SERVER_H
#define SERVER_H

#include <QObject>
#include <pulse/introspect.h>

namespace QPulseAudio
{

class Sink;
class Source;

class Q_DECL_EXPORT Server : public QObject
{
    Q_OBJECT

public:
    explicit Server(QObject *parent = nullptr);

    Sink *defaultSink() const;
    void setDefaultSink(Sink *sink);

    Source *defaultSource() const;
    void setDefaultSource(Source *source);

    void reset();
    void update(const pa_server_info *info);

signals:
    void defaultSinkChanged(Sink *sink);
    void defaultSourceChanged(Source *source);

private:
    Sink *m_defaultSink;
    Source *m_defaultSource;
};

} // QPulseAudio

#endif // CONTEXT_H

==> plasma-pa-5.9.0.tar.xz: plasma-pa-5.9.0/src/server.h <==
/*
    Copyright 2016 David Rosca <nowrep@gmail.com>

    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Lesser General Public
    License as published by the Free Software Foundation; either
    version 2.1 of the License, or (at your option) version 3, or any
    later version accepted by the membership of KDE e.V. (or its
    successor approved by the membership of KDE e.V.), which shall
    act as a proxy defined in Section 6 of version 3 of the license.

    This library is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
    Lesser General Public License for more details.

    You should have received a copy of the GNU Lesser General Public
    License along with this library.  If not, see <http://www.gnu.org/licenses/>.
*/

#ifndef SERVER_H
#define SERVER_H

#include <QObject>
#include <pulse/introspect.h>

namespace QPulseAudio
{

class Sink;
class Source;
class Context;

class Q_DECL_EXPORT Server : public QObject
{
    Q_OBJECT

public:
    explicit Server(Context *context);

    Sink *defaultSink() const;
    void setDefaultSink(Sink *sink);

    Source *defaultSource() const;
    void setDefaultSource(Source *source);

    void reset();
    void update(const pa_server_info *info);

signals:
    void defaultSinkChanged(Sink *sink);
    void defaultSourceChanged(Source *source);

private:
    void updateDefaultDevices();

    QString m_defaultSinkName;
    QString m_defaultSourceName;
    Sink *m_defaultSink;
    Source *m_defaultSource;
};

} // QPulseAudio

#endif // CONTEXT_H
